@@ -4,7 +4,7 @@ module System.Remote.Json
     , encodeOne
     ) where
 
-import qualified Data.Aeson.Encode as A
+import qualified Data.Aeson as A
 import qualified Data.ByteString.Lazy as L
 
 import System.Metrics
