@@ -18,7 +18,7 @@ import Network.Socket (NameInfoFlag(NI_NUMERICHOST), addrAddress, getAddrInfo,
                        getNameInfo)
 import Paths_ekg (getDataDir)
 import Prelude hiding (read)
-import Snap.Core (MonadSnap, Request, Snap, finishWith, getHeaders, getRequest,
+import Snap.Core (MonadSnap, Request, Snap, finishWith, getHeader, getRequest,
                   getResponse, method, Method(GET), modifyResponse, pass,
                   rqPathInfo, setContentType, setResponseStatus,
                   writeLBS)
@@ -78,7 +78,7 @@ monitor store = do
 
 -- | The Accept header of the request.
 acceptHeader :: Request -> Maybe S.ByteString
-acceptHeader req = S.intercalate "," <$> getHeaders "Accept" req
+acceptHeader req = getHeader "Accept" req
 
 -- | Runs a Snap monad action only if the request's Accept header
 -- matches the given MIME type.
